@@ -38,6 +38,7 @@ ARTEFACTS = [
     "fip.bin",
     "ubuntu.satadisk.xz",
     "startup.nsh",
+    "kselftest.tar.xz",
 ]
 
 FVP_MORELLO_ANDROID = [
@@ -722,6 +723,52 @@ def artefacts(tmp_path):
             ],
             "fvp-morello-busybox-purecap.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-morello-grub",
+                "--ap-romfw",
+                "tf-bl1.bin",
+                "--mcp-fw",
+                "mcp_fw.bin",
+                "--mcp-romfw",
+                "mcp_romfw.bin",
+                "--rootfs",
+                "debian.img.xz",
+                "--scp-fw",
+                "scp_fw.bin",
+                "--scp-romfw",
+                "scp_romfw.bin",
+                "--fip",
+                "fip.bin",
+                "--tests",
+                "boot-debian-dt",
+            ],
+            "fvp-morello-grub-boot-debian-dt.yaml",
+        ),
+        (
+            [
+                "--device",
+                "fvp-morello-grub",
+                "--ap-romfw",
+                "tf-bl1.bin",
+                "--mcp-fw",
+                "mcp_fw.bin",
+                "--mcp-romfw",
+                "mcp_romfw.bin",
+                "--rootfs",
+                "debian.img.xz",
+                "--scp-fw",
+                "scp_fw.bin",
+                "--scp-romfw",
+                "scp_romfw.bin",
+                "--fip",
+                "fip.bin",
+                "--tests",
+                "boot-busybox-dt",
+            ],
+            "fvp-morello-grub-boot-busybox-dt.yaml",
+        ),
         (
             [
                 "--device",
@@ -809,9 +856,20 @@ def artefacts(tmp_path):
             "fvp-morello-ubuntu.yaml",
         ),
         (
-            ["--tuxmake", "."],
+            ["--tuxmake", ".", "--tests", "kselftest-cgroup"],
             "tuxmake.yaml",
         ),
+        (
+            [
+                "--tuxmake",
+                ".",
+                "--tests",
+                "kselftest-cgroup",
+                "--parameters",
+                "KSELFTEST=$BUILD/kselftest.tar.xz",
+            ],
+            "tuxmake-parameters.yaml",
+        ),
     ],
 )
 def test_definition(monkeypatch, mocker, tmpdir, artefacts, args, filename):
